@@ -3,20 +3,19 @@
 package app
 
 import (
-	"strings"
-	"time"
-
-	"k8s.io/client-go/dynamic"
-
+	clusterv1client "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
+	clusterv1informers "github.com/open-cluster-management/api/client/cluster/informers/externalversions"
+	"github.com/open-cluster-management/multicloud-operators-foundation/cmd/proxyserver/app/options"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/proxyserver/controller"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/proxyserver/getter"
 	apilabels "k8s.io/apimachinery/pkg/labels"
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
-
-	"github.com/stolostron/multicloud-operators-foundation/cmd/proxyserver/app/options"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/proxyserver/controller"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/proxyserver/getter"
+	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/informers"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/tools/clientcmd"
+	"strings"
+	"time"
 )
 
 func Run(s *options.Options, stopCh <-chan struct{}) error {
@@ -48,11 +47,16 @@ func Run(s *options.Options, stopCh <-chan struct{}) error {
 		return err
 	}
 
+	clusterClient, err := clusterv1client.NewForConfig(clusterCfg)
+	if err != nil {
+		return err
+	}
+
+	clusterInformers := clusterv1informers.NewSharedInformerFactory(clusterClient, 10*time.Minute)
+
 	informerFactory := informers.NewSharedInformerFactory(kubeClient, 10*time.Minute)
 	proxyGetter := getter.NewProxyServiceInfoGetter()
 	ctrl := controller.NewProxyServiceInfoController(kubeClient, configMapLabels, informerFactory, proxyGetter, stopCh)
-	go ctrl.Run()
-	informerFactory.Start(stopCh)
 
 	apiServerConfig, err := s.APIServerConfig()
 	if err != nil {
@@ -64,9 +68,14 @@ func Run(s *options.Options, stopCh <-chan struct{}) error {
 		return nil
 	}
 
-	proxyServer, err := NewProxyServer(informerFactory, apiServerConfig, proxyGetter, logGetter)
+	proxyServer, err := NewProxyServer(clusterClient, informerFactory, clusterInformers, apiServerConfig, proxyGetter, logGetter)
 	if err != nil {
 		return err
 	}
+
+	go ctrl.Run()
+	clusterInformers.Start(stopCh)
+	informerFactory.Start(stopCh)
+
 	return proxyServer.Run(stopCh)
 }
