@@ -14,7 +14,7 @@ fi
 rm -rf registration-operator
 
 echo "############  Cloning registration-operator"
-git clone --depth 1 --branch v0.5.0 https://github.com/open-cluster-management-io/registration-operator.git
+git clone https://github.com/open-cluster-management/registration-operator.git
 
 cd registration-operator || {
   printf "cd failed, registration-operator does not exist"
@@ -22,7 +22,7 @@ cd registration-operator || {
 }
 
 echo "############  Deploying hub"
-make deploy-hub GO_REQUIRED_MIN_VERSION:=
+make deploy-hub
 if [ $? -ne 0 ]; then
  echo "############  Failed to deploy hub"
  exit 1
